## Template for bug report

Thank you for taking the time to fill out this bug report!
Use this template to report if something doesn't work quite right.

### Issue Description
Please provide a description of the issue here.


### Reproducible example
Please provide a minimal, copy-pastable code example if possible.
``` python
# Copy-paste code here
...

```

### Expected behavior
Please describe or show the expected behavior.


### Installed Versions
Please share information on your environment. 
Paste the output below.  For pip `pip freeze` and for conda `conda env export`.


### Checklist

- [ ] I have confirmed that this bug exists on the current branch of demoses-coupling:
      [`main`](https://gitlab.tudelft.nl/demoses/cronian/-/tree/main)
- [ ] I have checked the list of [existing issues](https://gitlab.tudelft.nl/demoses/cronian/-/issues) and couldn't find an issue about this bug.


/label ~Bug